﻿// Copyright (c) Microsoft Open Technologies, Inc. All rights reserved.
// Licensed under the Apache License, Version 2.0. See License.txt in the project root for license information.

using System;
using System.IO;
using System.Threading;
using Microsoft.Azure.WebJobs.Host.Blobs;
using Microsoft.Azure.WebJobs.Host.Queues;
using Microsoft.WindowsAzure.Storage;

namespace Microsoft.Azure.WebJobs.Host.Bindings
{
    internal class ValueBindingContext
    {
        private readonly FunctionBindingContext _functionContext;
        private readonly CancellationToken _cancellationToken;

        public ValueBindingContext(FunctionBindingContext functionContext, CancellationToken cancellationToken)
        {
            _functionContext = functionContext;
            _cancellationToken = cancellationToken;
        }

        public FunctionBindingContext FunctionContext
        {
            get { return _functionContext; }
        }

        public IBindingProvider BindingProvider
        {
            get { return _functionContext.BindingProvider; }
        }

        public INameResolver NameResolver
        {
            get { return _functionContext.NameResolver; }
        }

        public CloudStorageAccount StorageAccount
        {
            get { return _functionContext.StorageAccount; }
        }

        public string ServiceBusConnectionString
        {
            get { return _functionContext.ServiceBusConnectionString; }
        }

        public IBlobWrittenWatcher BlobWrittenWatcher
        {
            get { return _functionContext.BlobWrittenWatcher; }
        }

        public IMessageEnqueuedWatcher MessageEnqueuedWatcher
        {
            get { return _functionContext.MessageEnqueuedWatcher; }
        }

        public Guid FunctionInstanceId
        {
            get { return _functionContext.FunctionInstanceId; }
        }

        public CancellationToken FunctionCancellationToken
        {
            get { return _functionContext.FunctionCancellationToken; }
        }

        public TextWriter ConsoleOutput
        {
            get { return _functionContext.ConsoleOutput; }
        }

        public CancellationToken CancellationToken
        {
            get { return _cancellationToken; }
        }
    }
}
